summaryrefslogtreecommitdiffstats
path: root/chrome/browser/tab_util.h
diff options
context:
space:
mode:
Diffstat (limited to 'chrome/browser/tab_util.h')
-rw-r--r--chrome/browser/tab_util.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/chrome/browser/tab_util.h b/chrome/browser/tab_util.h
index 6aa96f3..9b576e5 100644
--- a/chrome/browser/tab_util.h
+++ b/chrome/browser/tab_util.h
@@ -5,8 +5,8 @@
#ifndef CHROME_BROWSER_TAB_UTIL_H__
#define CHROME_BROWSER_TAB_UTIL_H__
+class TabContents;
class URLRequest;
-class WebContents;
namespace tab_util {
@@ -15,10 +15,10 @@ namespace tab_util {
bool GetTabContentsID(URLRequest* request, int* render_process_host_id,
int* routing_id);
// Helper to find the WebContents that originated the given request. Can be
// NULL if the tab has been closed or some other error occurs.
// Should only be called from the UI thread, since it accesses TabContent.
-WebContents* GetWebContentsByID(int render_process_host_id, int routing_id);
+TabContents* GetTabContentsByID(int render_process_host_id, int routing_id);
} // namespace tab_util
@@ -15,10 +15,10 @@ namespace tab_util {
bool GetTabContentsID(URLRequest* request, int* render_process_host_id,
int* routing_id);
-// Helper to find the WebContents that originated the given request. Can be
+// Helper to find the TabContents that originated the given request. Can be
// NULL if the tab has been closed or some other error occurs.
// Should only be called from the UI thread, since it accesses TabContent.